@@ -22,6 +22,7 @@ from wx.adv import (
     SplashScreen,
 )
 
+from .applicationInfo import ApplicationInfo
 from .applicationWindow import ApplicationWindow
 from .artprovider import Artprovider
 from .document import DOC_SILENT
@@ -150,32 +151,28 @@ class App(wx.App):
 
     def __init__(
         self,
-        about: Optional[AboutDialogInfo] = None,
         pluginDir: Optional[str] = None,
         redirect: bool = False,
         debug: int = 1,
         iconName: str = "",
+        test=False,
     ):
-        """Constructor
-
-        Args:
-            about (wx.adv.AboutDialogInfo): Application info with name, vendor, version etc.
+        """
+        Constructor
         """
         self._debug: int = debug
-        self.about: Optional[AboutDialogInfo] = about
         self.iconName: str = iconName
+        self._test = test
         self._splashScreen: Optional[AppSplashScreen] = None
+        self.info:ApplicationInfo = self._getAppInfo()
         self.cmdLineArguments: Namespace = self._getCmdLineArguments()
         self._extChangeMode: int = self.EXT_CHANGE_TEST_ON_REQUEST
         self.extChangeTimerInterval: int = 60
         self.folder: str = os.path.dirname(sys.argv[0])
         self.sharedDataDir: str = ""
         self.privateDataDir: str = ""
-        self.privateDataDir: str = ""
-        self.enterMainLoop: bool = False
         self.globalObjects: List[str] = []
-        if isinstance(about, AboutDialogInfo):
-            self.dirs = AppDirs(about.Name, about.Vendor)
+        self.dirs = AppDirs(self.info.AppName, self.info.VendorName)
         if self.folder not in sys.path:
             sys.path.insert(0, self.folder)
         if pluginDir and os.path.isdir(pluginDir):
@@ -191,39 +188,54 @@ class App(wx.App):
     # Private methods
     # =========================================================================
 
+    def _getAppInfo(self) -> ApplicationInfo:
+        if not self.test:
+            appInfoString = self.getResource("application.yml")
+            if isinstance(appInfoString, str):
+                return ApplicationInfo.fromString(appInfoString)
+        return ApplicationInfo()
+
     def _getCmdLineArguments(self) -> Namespace:
         """
         :return: parsed command line arguments
         """
+        if self.test:
+            return Namespace(document=[], disabledPlugins=[])
         # Setup the ArgumentParser
-        if self.about:
-            argumentParser = ArgumentParser(
-                self.about.Name, description=self.about.Description
-            )
-            argumentParser.add_argument(
-                "document",
-                type=str,
-                nargs="*",
-                help="Documents to open",
-            )
-            argumentParser.add_argument(
-                "-x",
-                "--eXecute",
-                type=str,
-                dest="scriptPath",
-                help="Execute a script after documents are loaded, if any",
-            )
-            argumentParser.add_argument(
-                "-s",
-                "--noStartupscript",
-                action="store_false",
-                default=True,
-                dest="start_script_exec",
-                help="Don't exceute the startup script, even if enabled in the apps preferences",
-            )
-            # return parsed arguments
-            return argumentParser.parse_args(sys.argv[1:])
-        return Namespace()
+        argumentParser = ArgumentParser(description=self.info.Description)
+        argumentParser.add_argument(
+            "document",
+            type=str,
+            nargs="*",
+            help="Documents to open",
+        )
+        argumentParser.add_argument(
+            "-x",
+            "--eXecute",
+            type=str,
+            metavar="scriptPath",
+            dest="scriptPath",
+            help="Execute a script after documents are loaded, if any.",
+        )
+        argumentParser.add_argument(
+            "-s",
+            "--noStartupscript",
+            action="store_false",
+            default=True,
+            dest="start_script_exec",
+            help="Don't exceute the startup script, even if enabled in the apps preferences.",
+        )
+        argumentParser.add_argument(
+            "-d",
+            "--DisablePlugin",
+            type=str,
+            nargs="*",
+            metavar="pluginName",
+            dest="disabledPlugins",
+            help="Don't load the specified plugins.",
+        )
+        # return parsed arguments
+        return argumentParser.parse_args(sys.argv[1:])
 
     def _handleCmdLineArguments(self):
         """
@@ -255,6 +267,8 @@ class App(wx.App):
             self.extChangeMode = cfg.ReadInt("Mode", self.EXT_CHANGE_TEST_ON_REQUEST)
 
     def _showSplashScreen(self):
+        if self.test:
+            return None
         cfg = self.config
         if not cfg.ReadBool("/Application/Start/showSplashScreen", True):
             return None
@@ -280,7 +294,7 @@ class App(wx.App):
                     x = round(cfg.ReadInt("x", -1) + (width - bmp.Width) / 2)
                     y = round(cfg.ReadInt("y", -1) + (height - bmp.Height) / 2)
                     pos = wx.Point(x, y)
-                    size = wx.Size(cfg.ReadInt("width", -1), cfg.ReadInt("height", -1))
+                    # size = wx.Size(cfg.ReadInt("width", -1), cfg.ReadInt("height", -1))
                     splashScreen = AppSplashScreen(
                         bitmap=bmp,
                         splashStyle=SPLASH_NO_TIMEOUT,
@@ -310,10 +324,12 @@ class App(wx.App):
             "app",
             "wx",
         ]
-        if self.about:
-            self.SetAppName(self.about.Name)
-            self.SetVendorName(self.about.Vendor)
-        self.config = self.Traits.CreateConfig()
+        for attr in ("AppName", "AppDisplayName", "VendorName", "VendorDisplayName"):
+            setattr(self, attr, getattr(self.info, attr))
+        if self.test:
+            self.config = wx.FileConfig()
+        else:
+            self.config = self.Traits.CreateConfig()
         self.instanceChecker = wx.SingleInstanceChecker(
             f"{self.AppName}-{wx.GetUserId()}"
         )
@@ -324,44 +340,73 @@ class App(wx.App):
             self.SetAssertMode(wx.APP_ASSERT_SUPPRESS)
 
     def OnInit(self) -> bool:
-        self.enterMainLoop = True
         self.prepareSingleInstanceConfig()
-        if self.enterMainLoop:
-            #     return False
-            self._splashScreen = self._showSplashScreen()
-            self.splashMessage("loading Plugins")
-            self._pluginManager: PluginManager = self.pluginManagerClass()
-            self.splashMessage("Plugins loaded")
-            if self.about:
-                self.SetTopWindow(self.topWindowClass(self.iconName))
-                self.splashMessage("main application window created")
-                self.prepareSharedDataFolder()
-                self.preparePrivateDataFolder()
-                self.TopWindow.Show(True)
-                self.RunPostInitQueue()
-                self._initExtChangesTest()
-                self._handleCmdLineArguments()
-            if self._splashScreen:
-                self._splashScreen.Destroy()
-                self._splashScreen = None
+        self._splashScreen = self._showSplashScreen()
+        self._pluginManager: PluginManager = self.pluginManagerClass()
+        self.SetTopWindow(self.topWindowClass(self.iconName))
+        self.prepareSharedDataFolder()
+        self.preparePrivateDataFolder()
+        self.RunPostInitQueue()
+        self._initExtChangesTest()
         return True
 
-    def MainLoop(self) -> None:
+    def OnRun(self) -> int:
         """
-        Execute the main GUI event loop.
+        Run the application
+
+            - Show the main application window
+            - handle command line arguments
+            - close the splash screen
+            - enter the main application event loop
+
+        :return: Return code
         """
-        if self.enterMainLoop:
-            self.enterMainLoop = False
-            super().MainLoop()
+        self.TopWindow.Show(True)
+        self._handleCmdLineArguments()
+        if self._splashScreen:
+            self._splashScreen.Destroy()
+            self._splashScreen = None
+        return super().OnRun()
+
+    def run(self) -> int:
+        """
+        Start the application by calling :meth:`OnRun`
+
+        :return: Return code
+        """
+        return self.OnRun()
 
     def splashMessage(self, text: str) -> None:
+        """
+        Show progress message on splash screen during initialisation
+        of the application.
+
+        :param text: The message
+        """
         if self._splashScreen:
             self._splashScreen.setMessage(text)
 
+    @property
+    def test(self) -> bool:
+        """
+        Turns the application in test mode. This disables the splash screen 
+        and doesn't create directories, files or registry entries
+
+        :return: Test mode enabled
+        """
+        return self._test
+
     @property
     def extChangeMode(self) -> int:
         """
-        Mode how external changes in documents should be checked.
+        Mode how external changes of documents should be checked.
+
+        May be one of:
+            - EXT_CHANGE_TEST_ON_REQUEST
+            - EXT_CHANGE_TEST_ON_ACTIVATE
+            - EXT_CHANGE_TEST_ON_TIMER
+        
+        :return: current mode
         """
         return self._extChangeMode
 
@@ -398,6 +443,17 @@ class App(wx.App):
         """The document manager of the running application"""
         return self.TopWindow.documentManager
 
+    @property
+    def version(self) -> str:
+        """
+        :return: The version string of the running application.
+        """
+        try:
+            return metadata.version(self.__class__.__module__)
+        except metadata.PackageNotFoundError:
+            return "0.0.0"
+
+
     def getResource(self, name: str, type: str = "str") -> Optional[Union[str, bytes]]:
         if type not in ("str", "bytes"):
             raise ValueError(
@@ -435,6 +491,8 @@ class App(wx.App):
         return None
 
     def prepareSingleInstanceConfig(self) -> None:
+        if self.test:
+            return
         self.allowMultipleInstances = self.config.ReadBool(
             "/Application/Start/MultipleInstances", False
         )
@@ -483,7 +541,6 @@ class App(wx.App):
                             break
                         else:
                             time.sleep(1)  # give enough time for buffer to be available
-                self.enterMainLoop = False
             else:
                 self.listenAndLoadTimer.Start(250)
 
@@ -496,7 +553,7 @@ class App(wx.App):
             url = cfg.Read("URL", "")
             pull_on_start = cfg.ReadBool("PullOnStart", False)
             if folder:
-                if not os.path.isdir(folder):
+                if not os.path.isdir(folder) and not self.test:
                     try:
                         os.makedirs(folder)
                     except PermissionError:
@@ -525,6 +582,8 @@ class App(wx.App):
                     self.pullSharedData()
 
     def pullSharedData(self) -> None:
+        if self.test:
+            return
         if has_git:
             if self.sharedDataDir:
                 try:
@@ -551,7 +610,7 @@ class App(wx.App):
         defaultFolder = os.path.join(self.dirs.user_data_dir, "private")
         with wx.ConfigPathChanger(cfg, "/Application/PrivateData/"):
             folder = cfg.Read("Dir", defaultFolder)
-            if not os.path.isdir(folder):
+            if not os.path.isdir(folder) and not self.test:
                 os.makedirs(folder)
             self.privateDataDir = folder
 
