@@ -42,7 +42,6 @@ class ApplicationWindow(wx.Frame):
     """
 
     panelManagerClass: ClassVar[type[PanelManager]] = PanelManager
-    pluginManagerClass: ClassVar[type[PluginManager]] = PluginManager
     documentManagerClass: ClassVar[type[DocumentManager]] = DocumentManager
 
     MenuBar: wx.MenuBar
@@ -51,15 +50,11 @@ class ApplicationWindow(wx.Frame):
         self._toolbarEdit: Optional[aui.AuiToolBar] = None
         self._showTooltip: bool = False
         app: App = wx.GetApp()
-        title: str = ""
-        self.about = about = app.about
-        if about:
-            title = about.Name
         wx.Frame.__init__(
             self,
             parent=None,
             id=wx.ID_ANY,
-            title=title,
+            title=app.info.AppDisplayName,
             pos=wx.DefaultPosition,
             size=wx.DefaultSize,
             style=wx.DEFAULT_FRAME_STYLE | wx.TAB_TRAVERSAL,
@@ -70,7 +65,6 @@ class ApplicationWindow(wx.Frame):
         self._menubar = wx.MenuBar()
         self.CreateStatusBar(3, wx.STB_SIZEGRIP, wx.ID_ANY)
         self.loadConfig()
-        # self._pluginManager: PluginManager = self.pluginManagerClass()
         self._documentManager: DocumentManager = self.documentManagerClass(self)
         self._panelManager: PanelManager = self.panelManagerClass(self)
         app.splashMessage("building menus")
@@ -139,10 +133,10 @@ class ApplicationWindow(wx.Frame):
         )
         self.Bind(wx.EVT_UPDATE_UI, self.on_update_replace, id=wx.ID_REPLACE)
 
+        app.splashMessage("main application window created")
+
     def __repr__(self):
-        if self.about:
-            return '<Application Window of "%s">' % self.about.Name
-        return "<Application Window>"
+        return f'<Application Window of {self.app.info.AppName}">'
 
     # -----------------------------------------------------------------------------
     # Properties
@@ -299,20 +293,19 @@ class ApplicationWindow(wx.Frame):
     def buildScriptsMenu(self) -> None:
         macroFolders = []
         cfg = self.config
-        if self.about:
-            with wx.ConfigPathChanger(cfg, "/Application/"):
-                macroFolders.append(
-                    os.path.join(
-                        cfg.Read("SharedData/Dir", self.app.sharedDataDir),
-                        "Macro",
-                    )
-                )
-                macroFolders.append(
-                    os.path.join(
-                        cfg.Read("PrivateData/Dir", self.app.privateDataDir),
-                        "Macro",
-                    ),
+        with wx.ConfigPathChanger(cfg, "/Application/"):
+            macroFolders.append(
+                os.path.join(
+                    cfg.Read("SharedData/Dir", self.app.sharedDataDir),
+                    "Macro",
                 )
+            )
+            macroFolders.append(
+                os.path.join(
+                    cfg.Read("PrivateData/Dir", self.app.privateDataDir),
+                    "Macro",
+                ),
+            )
         for macroFolder in macroFolders:
             if not os.path.isdir(macroFolder):
                 os.makedirs(macroFolder)
@@ -570,7 +563,13 @@ class ApplicationWindow(wx.Frame):
             prefDlg.ShowModal()
 
     def on_help_about(self, event: wx.CommandEvent):
-        adv.AboutBox(self.app.about)
+        appInfo = self.app.info
+        info = adv.AboutDialogInfo()
+        info.Name = appInfo.AppDisplayName
+        info.Version = self.app.version
+        info.Description = appInfo.Description
+        info.Copyright = appInfo.Copyright
+        adv.AboutBox(info)
 
     def on_help_about_plugin(self, event: wx.CommandEvent):
         message = "Plugin version info\n============================\n"
